@@ -4,18 +4,32 @@ use warnings;
 
 package Devel::Main;
 
-our $VERSION = 0.004;
+our $VERSION = 0.005;
 
-# We use Sub::Exporter so you can import main with different names
-# with 'use Devel::Main 'main' => { -as => 'other' }
-use Sub::Exporter 0.985;
-Sub::Exporter::setup_exporter(
-    {
-        exports => {
-            'main' => \&main_generator
-        }
+sub import {
+    my $class  = shift;
+    @_ = 'main' unless @_;
+    
+    my $opts   = ref($_[0]) ? shift : {};
+    my $caller = $opts->{into} // scalar(caller($opts->{into_level} // 0));
+    
+    while (@_) {
+        my $name = shift;
+        my $args = ref($_[0]) ? shift : {};
+        my $gen  = $class->can("$name\_generator")
+            or do { require Carp; Carp::croak("$class does not export sub '$name'") };
+        my $code = $gen->( $class, $name, $args );
+        
+        my $as = join '', grep defined, (
+            $args->{ -prefix },
+            ($args->{ -as } // $name),
+            $args->{ -suffix },
+        );
+        
+        no strict 'refs';
+        *{"$caller\::$as"} = $code;
     }
-);
+}
 
 sub main_generator {
     my ( $class, $name, $args ) = @_;
@@ -59,7 +73,7 @@ Devel::Main - Syntactic sugar for a script's main routine
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -120,7 +134,8 @@ Finally, you can change the name of the subroutine to call the main routine via
 
 =head1 CREDITS
 
-This module was inspired by Brian D. Foy's article "Five Ways to Improve Your Perl Programming" (http://www.onlamp.com/2007/04/12/five-ways-to-improve-your-perl-programming.html).
+This module was inspired by brian d foy's article
+L<Five Ways to Improve Your Perl Programming|http://www.onlamp.com/2007/04/12/five-ways-to-improve-your-perl-programming.html>.
 
 =head1 AUTHOR
 
